==> sagua_0.2.3-1.tar.gz: sagua-0.2.3/include/player_mp3.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mod: nil; c-basic-offset: 4 -*- */
#ifndef GUARD_player_mp3_h
#define GUARD_player_mp3_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file player_mp3.h
/// @brief Class for play mp3 header file.

#include <unistd.h>
#include <sys/stat.h>
#include <sys/mman.h>
#include <fcntl.h>

#include <vector>
#include <string>

#include <glibmm.h>

#include <mad.h>
#include "player.h"

class MainManager;

namespace MAD {

    struct buffer {
        unsigned char* fdm;
        unsigned char* data;
        unsigned long length;

        int fd;
        int eof;

        struct stat stat;
    };

    struct Timer {
        mad_timer_t playTimer_;
        unsigned long playFrameCount_;
    };

    /// @brief Class for play mp3.
    ///
    /// MAD requires static function, almost member functions and variables are static.
    class MP3Player : public Player 
    {
    public:
        MP3Player(MainManager& mainManager);
        virtual ~MP3Player();

        virtual bool Init(const std::string& filename);

        virtual void Start();

        virtual void Stop(); 
	    
        virtual void Seek(const unsigned long& seconds);

    private:
        MP3Player& operator=(const MP3Player& mp3Player);
        MP3Player(const MP3Player& mp3Player);
	
        static MainManager* mainManager_;		///< Program control MainManager
	    
        Glib::Dispatcher signalFinish_;		///< Dispatcher for finish signal
        static std::vector<double> bufSample_;	///< Container to store decoded samples

        static std::string filename_;

        struct mad_decoder decoder_;
        struct buffer buf_;	
	    
        static DecodeState decodeState_;
        static unsigned int sampleRate_;
        static Timer timer_;
        static long seekSeconds_;

        void Clean();
	    
        void Reset();

        static enum mad_flow Input(void* data, struct mad_stream* stream);
        static enum mad_flow Output(void* data, struct mad_header const* header, struct mad_pcm* pcm);
        static enum mad_flow Header(void* data, struct mad_header const* header);
        static enum mad_flow Error(void* data, struct mad_stream* stream, struct mad_frame* frame); 
    };

}

std::auto_ptr<Player> CreateMP3Player(MainManager& mainManager);

#endif

==> sagua_0.2.4-1.tar.gz: sagua-0.2.4/include/player_mp3.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mod: nil; c-basic-offset: 4 -*- */
#ifndef GUARD_player_mp3_h
#define GUARD_player_mp3_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file player_mp3.h
/// @brief Class for play mp3 header file.

#include <unistd.h>
#include <sys/stat.h>
#include <sys/mman.h>
#include <fcntl.h>

#include <string>

#include <glibmm.h>

#include <mad.h>

#include "player.h"

#include "fwd.h"

/// @brief Namespace for class that use MAD library.
namespace MAD {

    struct buffer {
        buffer()
            : fdm(0),
              data(0),
              length(0),
              fd(-1),
              eof(true)
        {}

        unsigned char* fdm;
        unsigned char* data;
        unsigned long length;

        int fd;
        bool eof;

        struct stat stat;
    };

    /// @brief Class for play mp3.
    ///
    /// MAD requires static function, almost member functions and variables are static.
    template <class Buffer>
    class MP3Player : public Player 
    {
    public:
        MP3Player(Buffer& buffer, const std::string& filename);
        ~MP3Player()
        {}

    private:
        MP3Player& operator=(const MP3Player& mp3Player);
        MP3Player(const MP3Player& mp3Player);

        static Buffer* buffer_;
        static PlayerInterface* playerInterface_;
	    
        Glib::Dispatcher signalFinish_;		///< Dispatcher for finish signal

        static std::string filename_;

        struct mad_decoder decoder_;
        struct buffer buf_;	
	    
        static DecodeState decodeState_;
        static mad_timer_t timer_;
        static long seekSeconds_;

        void DoStart();

        void DoStop(); 
	    
        void DoSeek(unsigned long time);

        void Init();

        void Clean();
	    
        void ResetStatic();

        bool Rewind();

        static enum mad_flow Input(void* data, struct mad_stream* stream);
        static enum mad_flow Output(void* data, struct mad_header const* header, struct mad_pcm* pcm);
        static enum mad_flow Header(void* data, struct mad_header const* header);
    };
}

template <class Buffer>
std::auto_ptr<Player> CreateMP3Player(Buffer& buffer, const std::string& filename);

#endif
